Django-Access-Select2
======================

The application providing a filtering for the Django-Select2 package using Django-Access package.

See details at the home page: https://github.com/nnseva/django-access-select2
